..
      Copyright European Organization for Nuclear Research (CERN)

      Licensed under the Apache License, Version 2.0 (the "License");
      You may not use this file except in compliance with the License.
      You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

===============
Rucio CLI Tools
===============

..
..    man/rucio-admin

Rucio provides two command-line tools:

 * :doc:`man/rucio-admin`: Utility for managing and configuring Rucio.
 * :doc:`man/rucio`: Utility for interacting with Rucio.

Examples with rucio-admin command-line tools can be found here: :doc:`cli_admin_examples`.

Examples with rucio command-line tools can be found here: :doc:`cli_examples`.

